@@ -34,21 +34,22 @@ class CallSuper(Exception):
     """Raised when the caller should call the superclass instead."""
 
 
-def custom_headers():
+def custom_headers(url):
     """Get the combined custom headers."""
     headers = {}
 
-    dnt_config = config.val.content.headers.do_not_track
+    dnt_config = config.instance.get('content.headers.do_not_track', url=url)
     if dnt_config is not None:
         dnt = b'1' if dnt_config else b'0'
         headers[b'DNT'] = dnt
         headers[b'X-Do-Not-Track'] = dnt
 
-    conf_headers = config.val.content.headers.custom
+    conf_headers = config.instance.get('content.headers.custom', url=url)
     for header, value in conf_headers.items():
         headers[header.encode('ascii')] = value.encode('ascii')
 
-    accept_language = config.val.content.headers.accept_language
+    accept_language = config.instance.get('content.headers.accept_language',
+                                          url=url)
     if accept_language is not None:
         headers[b'Accept-Language'] = accept_language.encode('ascii')
 
@@ -156,7 +157,7 @@ def ignore_certificate_errors(url, errors, abort_on):
     Return:
         True if the error should be ignored, False otherwise.
     """
-    ssl_strict = config.val.content.ssl_strict
+    ssl_strict = config.instance.get('content.ssl_strict', url=url)
     log.webview.debug("Certificate errors {!r}, strict {}".format(
         errors, ssl_strict))
 
@@ -196,7 +197,8 @@ def ignore_certificate_errors(url, errors, abort_on):
     raise utils.Unreachable
 
 
-def feature_permission(url, option, msg, yes_action, no_action, abort_on):
+def feature_permission(url, option, msg, yes_action, no_action, abort_on,
+                       blocking=False):
     """Handle a feature permission request.
 
     Args:
@@ -206,11 +208,13 @@ def feature_permission(url, option, msg, yes_action, no_action, abort_on):
         yes_action: A callable to call if the request was approved
         no_action: A callable to call if the request was denied
         abort_on: A list of signals which interrupt the question.
+        blocking: If True, ask a blocking question.
 
     Return:
-        The Question object if a question was asked, None otherwise.
+        The Question object if a question was asked (and blocking=False),
+        None otherwise.
     """
-    config_val = config.instance.get(option)
+    config_val = config.instance.get(option, url=url)
     if config_val == 'ask':
         if url.isValid():
             urlstr = url.toString(QUrl.RemovePassword | QUrl.FullyEncoded)
@@ -220,10 +224,20 @@ def feature_permission(url, option, msg, yes_action, no_action, abort_on):
             urlstr = None
             text = "Allow the website to {}?".format(msg)
 
-        return message.confirm_async(
-            yes_action=yes_action, no_action=no_action,
-            cancel_action=no_action, abort_on=abort_on,
-            title='Permission request', text=text, url=urlstr)
+        if blocking:
+            answer = message.ask(abort_on=abort_on, title='Permission request',
+                                 text=text, url=urlstr,
+                                 mode=usertypes.PromptMode.yesno)
+            if answer:
+                yes_action()
+            else:
+                no_action()
+            return None
+        else:
+            return message.confirm_async(
+                yes_action=yes_action, no_action=no_action,
+                cancel_action=no_action, abort_on=abort_on,
+                title='Permission request', text=text, url=urlstr)
     elif config_val:
         yes_action()
         return None
@@ -299,10 +313,10 @@ def netrc_authentication(url, authenticator):
             (user, _account, password) = authenticators
     except FileNotFoundError:
         log.misc.debug("No .netrc file found")
-    except OSError:
-        log.misc.exception("Unable to read the netrc file")
-    except netrc.NetrcParseError:
-        log.misc.exception("Error when parsing the netrc file")
+    except OSError as e:
+        log.misc.exception("Unable to read the netrc file: {}".format(e))
+    except netrc.NetrcParseError as e:
+        log.misc.exception("Error when parsing the netrc file: {}".format(e))
 
     if user is None:
         return False
