@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2017 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -23,12 +23,12 @@ Defines a CompletionView which uses CompletionFiterModel and CompletionModel
 subclasses to provide completions.
 """
 
-from PyQt5.QtWidgets import QStyle, QTreeView, QSizePolicy, QStyleFactory
+from PyQt5.QtWidgets import QTreeView, QSizePolicy, QStyleFactory
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QItemSelectionModel, QSize
 
 from qutebrowser.config import config
 from qutebrowser.completion import completiondelegate
-from qutebrowser.utils import utils, usertypes, debug, log
+from qutebrowser.utils import utils, usertypes, debug, log, objreg
 from qutebrowser.commands import cmdexc, cmdutils
 
 
@@ -152,12 +152,12 @@ class CompletionView(QTreeView):
         column_widths = self.model().column_widths
         pixel_widths = [(width * perc // 100) for perc in column_widths]
 
-        if self.verticalScrollBar().isVisible():
-            delta = self.style().pixelMetric(QStyle.PM_ScrollBarExtent) + 5
-            if pixel_widths[-1] > delta:
-                pixel_widths[-1] -= delta
-            else:
-                pixel_widths[-2] -= delta
+        delta = self.verticalScrollBar().sizeHint().width()
+        if pixel_widths[-1] > delta:
+            pixel_widths[-1] -= delta
+        else:
+            pixel_widths[-2] -= delta
+
         for i, w in enumerate(pixel_widths):
             assert w >= 0, i
             self.setColumnWidth(i, w)
@@ -180,6 +180,7 @@ class CompletionView(QTreeView):
                 return self.model().last_item()
             else:
                 return self.model().first_item()
+
         while True:
             idx = self.indexAbove(idx) if upwards else self.indexBelow(idx)
             # wrap around if we arrived at beginning/end
@@ -193,6 +194,8 @@ class CompletionView(QTreeView):
                 # Item is a real item, not a category header -> success
                 return idx
 
+        raise utils.Unreachable
+
     def _next_category_idx(self, upwards):
         """Get the index of the previous/next category.
 
@@ -222,30 +225,46 @@ class CompletionView(QTreeView):
                 self.scrollTo(idx)
                 return idx.child(0, 0)
 
-    @cmdutils.register(instance='completion', hide=True,
+        raise utils.Unreachable
+
+    @cmdutils.register(instance='completion',
                        modes=[usertypes.KeyMode.command], scope='window')
     @cmdutils.argument('which', choices=['next', 'prev', 'next-category',
                                          'prev-category'])
-    def completion_item_focus(self, which):
+    @cmdutils.argument('history', flag='H')
+    def completion_item_focus(self, which, history=False):
         """Shift the focus of the completion menu to another item.
 
         Args:
             which: 'next', 'prev', 'next-category', or 'prev-category'.
+            history: Navigate through command history if no text was typed.
         """
+        if history:
+            status = objreg.get('status-command', scope='window',
+                                window=self._win_id)
+            if (status.text() == ':' or status.history.is_browsing() or
+                    not self._active):
+                if which == 'next':
+                    status.command_history_next()
+                    return
+                elif which == 'prev':
+                    status.command_history_prev()
+                    return
+                else:
+                    raise cmdexc.CommandError("Can't combine --history with "
+                                              "{}!".format(which))
+
         if not self._active:
             return
-        selmodel = self.selectionModel()
 
-        if which == 'next':
-            idx = self._next_idx(upwards=False)
-        elif which == 'prev':
-            idx = self._next_idx(upwards=True)
-        elif which == 'next-category':
-            idx = self._next_category_idx(upwards=False)
-        elif which == 'prev-category':
-            idx = self._next_category_idx(upwards=True)
-        else:  # pragma: no cover
-            raise ValueError("Invalid 'which' value {!r}".format(which))
+        selmodel = self.selectionModel()
+        indices = {
+            'next': self._next_idx(upwards=False),
+            'prev': self._next_idx(upwards=True),
+            'next-category': self._next_category_idx(upwards=False),
+            'prev-category': self._next_category_idx(upwards=True),
+        }
+        idx = indices[which]
 
         if not idx.isValid():
             return
@@ -369,7 +388,7 @@ class CompletionView(QTreeView):
             scrollbar.setValue(scrollbar.minimum())
         super().showEvent(e)
 
-    @cmdutils.register(instance='completion', hide=True,
+    @cmdutils.register(instance='completion',
                        modes=[usertypes.KeyMode.command], scope='window')
     def completion_item_del(self):
         """Delete the current completion item."""
@@ -377,3 +396,21 @@ class CompletionView(QTreeView):
         if not index.isValid():
             raise cmdexc.CommandError("No item selected!")
         self.model().delete_cur_item(index)
+
+    @cmdutils.register(instance='completion',
+                       modes=[usertypes.KeyMode.command], scope='window')
+    def completion_item_yank(self, sel=False):
+        """Yank the current completion item into the clipboard.
+
+        Args:
+            sel: Use the primary selection instead of the clipboard.
+        """
+        status = objreg.get('status-command', scope='window',
+                            window=self._win_id)
+        text = status.selectedText()
+        if not text:
+            index = self.currentIndex()
+            if not index.isValid():
+                raise cmdexc.CommandError("No item selected!")
+            text = self.model().data(index)
+        utils.set_clipboard(text, selection=sel)
