@@ -276,7 +276,8 @@ class Config(QObject):
         """Set the given option to the given value."""
         if not isinstance(objects.backend, objects.NoBackend):
             if objects.backend not in opt.backends:
-                raise configexc.BackendError(opt.name, objects.backend)
+                raise configexc.BackendError(opt.name, objects.backend,
+                                             opt.raw_backends)
 
         opt.typ.to_py(value)  # for validation
 
