@@ -138,6 +138,37 @@ def _key_to_string(key):
         'Dead_Hook': 'Hook',
         'Dead_Horn': 'Horn',
 
+        'Dead_Stroke': '̵',
+        'Dead_Abovecomma': '̓',
+        'Dead_Abovereversedcomma': '̔',
+        'Dead_Doublegrave': '̏',
+        'Dead_Belowring': '̥',
+        'Dead_Belowmacron': '̱',
+        'Dead_Belowcircumflex': '̭',
+        'Dead_Belowtilde': '̰',
+        'Dead_Belowbreve': '̮',
+        'Dead_Belowdiaeresis': '̤',
+        'Dead_Invertedbreve': '̑',
+        'Dead_Belowcomma': '̦',
+        'Dead_Currency': '¤',
+        'Dead_a': 'a',
+        'Dead_A': 'A',
+        'Dead_e': 'e',
+        'Dead_E': 'E',
+        'Dead_i': 'i',
+        'Dead_I': 'I',
+        'Dead_o': 'o',
+        'Dead_O': 'O',
+        'Dead_u': 'u',
+        'Dead_U': 'U',
+        'Dead_Small_Schwa': 'ə',
+        'Dead_Capital_Schwa': 'Ə',
+        'Dead_Greek': 'Greek',
+        'Dead_Lowline': '̲',
+        'Dead_Aboveverticalline': '̍',
+        'Dead_Belowverticalline': '\u0329',
+        'Dead_Longsolidusoverlay': '̸',
+
         'Memo': 'Memo',
         'ToDoList': 'To Do List',
         'Calendar': 'Calendar',
