@@ -1,6 +1,6 @@
 # vim: ft=python fileencoding=utf-8 sts=4 sw=4 et:
 
-# Copyright 2014-2016 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+# Copyright 2014-2018 Florian Bruhin (The Compiler) <mail@qutebrowser.org>
 #
 # This file is part of qutebrowser.
 #
@@ -26,7 +26,7 @@ from PyQt5.QtCore import pyqtSignal, pyqtSlot, QObject, QUrl
 
 class PastebinClient(QObject):
 
-    """A client for http://p.cmpl.cc/ using HTTPClient.
+    """A client for Stikked pastebins using HTTPClient.
 
     Attributes:
         _client: The HTTPClient used.
@@ -41,23 +41,26 @@ class PastebinClient(QObject):
                arg: The error message, as string.
     """
 
-    API_URL = 'http://paste.the-compiler.org/api/'
+    API_URL = 'https://crashes.qutebrowser.org/api/'
+    MISC_API_URL = 'https://paste.the-compiler.org/api/'
     success = pyqtSignal(str)
     error = pyqtSignal(str)
 
-    def __init__(self, client, parent=None):
+    def __init__(self, client, parent=None, api_url=API_URL):
         """Constructor.
 
         Args:
             client: The HTTPClient to use. Will be reparented.
+            api_url: The Stikked pastebin endpoint to use.
         """
         super().__init__(parent)
         client.setParent(self)
         client.error.connect(self.error)
         client.success.connect(self.on_client_success)
         self._client = client
+        self._api_url = api_url
 
-    def paste(self, name, title, text, parent=None):
+    def paste(self, name, title, text, parent=None, private=False):
         """Paste the text into a pastebin and return the URL.
 
         Args:
@@ -65,6 +68,7 @@ class PastebinClient(QObject):
             title: The post title.
             text: The text to post.
             parent: The parent paste to reply to.
+            private: Whether to paste privately.
         """
         data = {
             'text': text,
@@ -74,7 +78,10 @@ class PastebinClient(QObject):
         }
         if parent is not None:
             data['reply'] = parent
-        url = QUrl(urllib.parse.urljoin(self.API_URL, 'create'))
+        if private:
+            data['private'] = '1'
+
+        url = QUrl(urllib.parse.urljoin(self._api_url, 'create'))
         self._client.post(url, data)
 
     @pyqtSlot(str)
