@@ -70,8 +70,10 @@ class SqliteError(SqlError):
         environmental_errors = [
             '5',   # SQLITE_BUSY ("database is locked")
             '8',   # SQLITE_READONLY
+            '10',  # SQLITE_IOERR
             '11',  # SQLITE_CORRUPT
             '13',  # SQLITE_FULL
+            '14',  # SQLITE_CANTOPEN
         ]
         # At least in init(), we can get errors like this:
         # type: ConnectionError
